@@ -55,8 +55,8 @@ def test_above_percent_iglu_r_compatible(scenario):
 
     # Compare DataFrames with precision to 0.001
     pd.testing.assert_frame_equal(
-        result_df.round(3),
-        expected_df.round(3),
+        result_df,
+        expected_df,
         check_dtype=False,  # Don't check dtypes since we might have different numeric types
         check_index_type=True,
         check_column_type=True,
@@ -68,6 +68,7 @@ def test_above_percent_iglu_r_compatible(scenario):
         check_like=True,
         check_freq=True,
         check_flags=True,
+        rtol=0.001,
     )
 
 
