@@ -15,6 +15,9 @@ def get_test_scenarios():
     with open("tests/expected_results.json", "r") as f:
         expected_results = json.load(f)
 
+    # set local timezone
+    iglu.utils.set_local_tz(expected_results["config"]["local_tz"])
+
     # Filter scenarios for range_glu method
     return [
         scenario
@@ -54,8 +57,8 @@ def test_range_glu_iglu_r_compatible(scenario):
 
     # Compare DataFrames with precision to 0.001 for numeric columns
     pd.testing.assert_frame_equal(
-        result_df.round(3),
-        expected_df.round(3),
+        result_df,
+        expected_df,
         check_dtype=False,  # Don't check dtypes since we might have different numeric types
         check_index_type=True,
         check_column_type=True,
@@ -67,6 +70,8 @@ def test_range_glu_iglu_r_compatible(scenario):
         check_like=True,
         check_freq=True,
         check_flags=True,
+    
+        rtol=0.001,
     )
 
 
